@@ -9,7 +9,11 @@ function __swcpack_require__(mod) {
             if (obj != null) {
                 for (var key in obj) {
                     if (Object.prototype.hasOwnProperty.call(obj, key)) {
-                        var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};
+                        var desc =
+                            Object.defineProperty &&
+                            Object.getOwnPropertyDescriptor
+                                ? Object.getOwnPropertyDescriptor(obj, key)
+                                : {};
 
                         if (desc.get || desc.set) {
                             Object.defineProperty(newObj, key, desc);
@@ -25,7 +29,6 @@ function __swcpack_require__(mod) {
         }
     }
 
-
     var cache;
 
     if (cache) {
@@ -33,10 +36,10 @@ function __swcpack_require__(mod) {
     }
 
     var module = {
-        exports: {}
+        exports: {},
     };
 
     mod(module, module.exports);
     cache = interop(module.exports);
     return cache;
-}
\ No newline at end of file
+}
